.. module:: enaml.widgets.splitter

======================
enaml.widgets.splitter
======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Splitter


.. autoclass:: Splitter
